"""Module with Bluetooth company IDs and their names.

Usage:

>>> from bluetooth_numbers import company
>>> company[0x0499]
'Ruuvi Innovations Ltd.'
"""
from bluetooth_numbers.dicts import CICDict

company = CICDict({  # 16-bit company IDs{% for code, name in cics.items() %}
    {{ code }}: "{{ name }}",
{%- endfor %}
})
